@@ -34,19 +34,19 @@
 GcomprisBoard *gcomprisBoard = NULL;
 gboolean board_paused = TRUE;
 
-static void start_board (GcomprisBoard *agcomprisBoard);
-static void pause_board (gboolean pause);
-static void end_board (void);
-static gboolean is_our_board (GcomprisBoard *gcomprisBoard);
-static void set_level (guint level);
+static void		 start_board (GcomprisBoard *agcomprisBoard);
+static void		 pause_board (gboolean pause);
+static void		 end_board (void);
+static gboolean		 is_our_board (GcomprisBoard *gcomprisBoard);
+static void		 set_level (guint level);
 static int gamewon;
 
-static void process_ok(void);
-static void highlight_selected(GnomeCanvasItem *);
-static void game_won();
+static void		 process_ok(void);
+static void		 highlight_selected(GnomeCanvasItem *);
+static void		 game_won(void);
 
 #ifdef DEBUG
-static void dump_xml();
+static void		 dump_xml(void);
 #endif
 
 
@@ -59,13 +59,13 @@ struct _Board {
 };
 
 /* XML */
-static gboolean read_xml_file(char *fname);
-static void init_xml();
-static void add_xml_data(xmlDocPtr doc,xmlNodePtr xmlnode, GNode * child);
-static void parse_doc(xmlDocPtr doc);
-static gboolean read_xml_file(char *fname);
-static void destroy_board_list();
-static void destroy_board(Board * board);
+static gboolean		 read_xml_file(char *fname);
+static void		 init_xml(void);
+static void		 add_xml_data(xmlDocPtr doc,xmlNodePtr xmlnode, GNode * child);
+static void		 parse_doc(xmlDocPtr doc);
+static gboolean		 read_xml_file(char *fname);
+static void		 destroy_board_list(void);
+static void		 destroy_board(Board * board);
 
 /* This is the list of boards */
 static GList *board_list = NULL;
@@ -193,6 +193,7 @@ end_board ()
       imageid_destroy_all_items();
       destroy_board_list();
     }
+  gcomprisBoard = NULL;
 }
 
 static void
@@ -304,7 +305,7 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
   /* display the 3 words */
   /* the right word is at position 0 : it is swapped with any position depending of place value */
 
-  gdk_font = gdk_font_load ("-adobe-times-medium-r-normal--*-240-*-*-*-*-*-*");
+  gdk_font = gdk_font_load (FONT_BOARD_BIG);
   switch (place) {
   case 1 :
     buf[0] = board->text2;
@@ -334,7 +335,7 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 				NULL);
   text1_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
-				      "text", _(buf[0]),
+				      "text", buf[0],
 				      "font_gdk", gdk_font,
 				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2,
 				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2,
@@ -351,7 +352,7 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 				NULL);
   text2_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
-				      "text", _(buf[1]),
+				      "text", buf[1],
 				      "font_gdk", gdk_font,
 				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2,
 				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2,
@@ -369,7 +370,7 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 
   text3_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
-				      "text", _(buf[2]),
+				      "text", buf[2],
 				      "font_gdk", gdk_font,
 				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2,
 				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2,
@@ -511,22 +512,30 @@ static void add_xml_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 	if (!strcmp(xmlnode->name, "pixmapfile") && (lang==NULL
 	    || !strcmp(lang, gcompris_get_locale())
 	    || !strncmp(lang, gcompris_get_locale(), 2)))
-		pixmapfile = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+	  {
+	    pixmapfile = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+	  }
 	if (!strcmp(xmlnode->name, "text1") && (lang==NULL
 	    || !strcmp(lang, gcompris_get_locale())
 	    || !strncmp(lang, gcompris_get_locale(), 2)))
+	  {
 		text1 = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
 		text1 = convertUTF8Toisolat1(text1);
+	  }
 	if (!strcmp(xmlnode->name, "text2") && (lang==NULL
 	    || !strcmp(lang, gcompris_get_locale())
 	    || !strncmp(lang, gcompris_get_locale(), 2)))
-		text2 = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
-		text2 = convertUTF8Toisolat1(text2);
+	  {
+	    text2 = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+	    text2 = convertUTF8Toisolat1(text2);
+	  }
 	if (!strcmp(xmlnode->name, "text3") && (lang==NULL
 	    || !strcmp(lang, gcompris_get_locale())
 	    || !strncmp(lang, gcompris_get_locale(), 2)))
-		text3 = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
-		text3 = convertUTF8Toisolat1(text3);
+	  {
+	    text3 = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 1);
+	    text3 = convertUTF8Toisolat1(text3);
+	  }
 	xmlnode = xmlnode->next;
 	}
 	// I really don't know why this test, but otherwise, the list is doubled
