@@ -1,6 +1,6 @@
 /* gcompris - properties.h
  *
- * Time-stamp: <2001/12/09 00:24:42 bruno>
+ * Time-stamp: <2002/05/01 22:13:04 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -26,10 +26,14 @@ typedef struct {
   gint		music;
   gint		fx;
   gint		fullscreen;
+  gint		screensize;
+  gint		defaultcursor;
+  gint		timer;
+  gchar	       *locale;
 } GcomprisProperties;
 
-GcomprisProperties	*gcompris_get_properties ();
-GcomprisProperties	*gcompris_properties_new ();
+GcomprisProperties	*gcompris_get_properties (void);
+GcomprisProperties	*gcompris_properties_new (void);
 void			 gcompris_properties_destroy (GcomprisProperties *props);
 GcomprisProperties	*gcompris_properties_copy (GcomprisProperties *props);
 void			 gcompris_properties_save (GcomprisProperties *props);
